# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .participant_repair_service_pb2 import ChangeAssignationRequest, ChangeAssignationResponse, ExportAcsOldRequest, ExportAcsOldResponse, ExportAcsRequest, ExportAcsResponse, IgnoreEventsRequest, IgnoreEventsResponse, ImportAcsOldRequest, ImportAcsOldResponse, ImportAcsRequest, ImportAcsResponse, MigrateSynchronizerRequest, MigrateSynchronizerResponse, PurgeContractsRequest, PurgeContractsResponse, PurgeDeactivatedSynchronizerRequest, PurgeDeactivatedSynchronizerResponse, RepairCommitmentsUsingAcsRequest, RepairCommitmentsUsingAcsResponse, RollbackUnassignmentRequest, RollbackUnassignmentResponse, UnignoreEventsRequest, UnignoreEventsResponse

__all__ = [
    "ParticipantRepairServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class ParticipantRepairServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _ParticipantRepairServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _ParticipantRepairServiceAsyncStub: ...  # type: ignore
    def ExportAcsOld(self, __1: ExportAcsOldRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsOldResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsOldResponse]: ...
    def ImportAcsOld(self, __1: _typing.Iterable[ImportAcsOldRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportAcsOldResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsOldResponse]: ...
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]: ...
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportAcsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsResponse]: ...
    def PurgeContracts(self, __1: PurgeContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeContractsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeContractsResponse]: ...
    def MigrateSynchronizer(self, __1: MigrateSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MigrateSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, MigrateSynchronizerResponse]: ...
    def ChangeAssignation(self, __1: ChangeAssignationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ChangeAssignationResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ChangeAssignationResponse]: ...
    def PurgeDeactivatedSynchronizer(self, __1: PurgeDeactivatedSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeDeactivatedSynchronizerResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeDeactivatedSynchronizerResponse]: ...
    def IgnoreEvents(self, __1: IgnoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> IgnoreEventsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, IgnoreEventsResponse]: ...
    def UnignoreEvents(self, __1: UnignoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UnignoreEventsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, UnignoreEventsResponse]: ...
    def RollbackUnassignment(self, __1: RollbackUnassignmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RollbackUnassignmentResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RollbackUnassignmentResponse]: ...
    def RepairCommitmentsUsingAcs(self, __1: RepairCommitmentsUsingAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RepairCommitmentsUsingAcsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, RepairCommitmentsUsingAcsResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantRepairServiceBlockingStub(ParticipantRepairServiceStub):
    def ExportAcsOld(self, __1: ExportAcsOldRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsOldResponse]: ...
    def ImportAcsOld(self, __1: _typing.Iterable[ImportAcsOldRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportAcsOldResponse: ...
    def ExportAcs(self, __1: ExportAcsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsResponse]: ...
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportAcsResponse: ...
    def PurgeContracts(self, __1: PurgeContractsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeContractsResponse: ...
    def MigrateSynchronizer(self, __1: MigrateSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MigrateSynchronizerResponse: ...
    def ChangeAssignation(self, __1: ChangeAssignationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ChangeAssignationResponse: ...
    def PurgeDeactivatedSynchronizer(self, __1: PurgeDeactivatedSynchronizerRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeDeactivatedSynchronizerResponse: ...
    def IgnoreEvents(self, __1: IgnoreEventsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> IgnoreEventsResponse: ...
    def UnignoreEvents(self, __1: UnignoreEventsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UnignoreEventsResponse: ...
    def RollbackUnassignment(self, __1: RollbackUnassignmentRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RollbackUnassignmentResponse: ...
    def RepairCommitmentsUsingAcs(self, __1: RepairCommitmentsUsingAcsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RepairCommitmentsUsingAcsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantRepairServiceAsyncStub(ParticipantRepairServiceStub):
    def ExportAcsOld(self, __1: ExportAcsOldRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsOldResponse]: ...  # type: ignore
    def ImportAcsOld(self, __1: _typing.Iterable[ImportAcsOldRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsOldResponse]: ...  # type: ignore
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]: ...  # type: ignore
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsResponse]: ...  # type: ignore
    def PurgeContracts(self, __1: PurgeContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeContractsResponse]: ...  # type: ignore
    def MigrateSynchronizer(self, __1: MigrateSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, MigrateSynchronizerResponse]: ...  # type: ignore
    def ChangeAssignation(self, __1: ChangeAssignationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ChangeAssignationResponse]: ...  # type: ignore
    def PurgeDeactivatedSynchronizer(self, __1: PurgeDeactivatedSynchronizerRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeDeactivatedSynchronizerResponse]: ...  # type: ignore
    def IgnoreEvents(self, __1: IgnoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, IgnoreEventsResponse]: ...  # type: ignore
    def UnignoreEvents(self, __1: UnignoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UnignoreEventsResponse]: ...  # type: ignore
    def RollbackUnassignment(self, __1: RollbackUnassignmentRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RollbackUnassignmentResponse]: ...  # type: ignore
    def RepairCommitmentsUsingAcs(self, __1: RepairCommitmentsUsingAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RepairCommitmentsUsingAcsResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nycom/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto\x12Scom.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1\"9\n\x0bSendRequest\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\"S\n\x0cSendResponse\x12.\n\x10rejection_reason\x18\x01 \x01(\tH\x00R\x0frejectionReason\x88\x01\x01\x42\x13\n\x11_rejection_reason\"7\n\x12ReadOrderedRequest\x12!\n\x0cstart_height\x18\x01 \x01(\x03R\x0bstartHeight\"\xa1\x01\n\x13ReadOrderedResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12r\n\x05\x62lock\x18\x02 \x03(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.OrderedR\x05\x62lock\"5\n\x07Ordered\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload2\xd1\x03\n\x1cStandaloneBftOrderingService\x12\xcb\x01\n\x04Send\x12`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.SendRequest\x1a\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.SendResponse\x12\xe2\x01\n\x0bReadOrdered\x12g.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.ReadOrderedRequest\x1ah.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.ReadOrderedResponse0\x01\x42\x85\x01Z\x82\x01github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.standalone_bft_ordering_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\202\001github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1'
  _globals['_SENDREQUEST']._serialized_start=210
  _globals['_SENDREQUEST']._serialized_end=267
  _globals['_SENDRESPONSE']._serialized_start=269
  _globals['_SENDRESPONSE']._serialized_end=352
  _globals['_READORDEREDREQUEST']._serialized_start=354
  _globals['_READORDEREDREQUEST']._serialized_end=409
  _globals['_READORDEREDRESPONSE']._serialized_start=412
  _globals['_READORDEREDRESPONSE']._serialized_end=573
  _globals['_ORDERED']._serialized_start=575
  _globals['_ORDERED']._serialized_end=628
  _globals['_STANDALONEBFTORDERINGSERVICE']._serialized_start=631
  _globals['_STANDALONEBFTORDERINGSERVICE']._serialized_end=1096
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .interactive_submission_service_pb2 import ExecuteSubmissionAndWaitForTransactionRequest, ExecuteSubmissionAndWaitForTransactionResponse, ExecuteSubmissionAndWaitRequest, ExecuteSubmissionAndWaitResponse, ExecuteSubmissionRequest, ExecuteSubmissionResponse, GetPreferredPackageVersionRequest, GetPreferredPackageVersionResponse, GetPreferredPackagesRequest, GetPreferredPackagesResponse, PrepareSubmissionRequest, PrepareSubmissionResponse

__all__ = [
    "InteractiveSubmissionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class InteractiveSubmissionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _InteractiveSubmissionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _InteractiveSubmissionServiceAsyncStub: ...  # type: ignore
    def PrepareSubmission(self, __1: PrepareSubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PrepareSubmissionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, PrepareSubmissionResponse]: ...
    def ExecuteSubmission(self, __1: ExecuteSubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionResponse]: ...
    def ExecuteSubmissionAndWait(self, __1: ExecuteSubmissionAndWaitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionAndWaitResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionAndWaitResponse]: ...
    def ExecuteSubmissionAndWaitForTransaction(self, __1: ExecuteSubmissionAndWaitForTransactionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionAndWaitForTransactionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionAndWaitForTransactionResponse]: ...
    def GetPreferredPackageVersion(self, __1: GetPreferredPackageVersionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPreferredPackageVersionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetPreferredPackageVersionResponse]: ...
    def GetPreferredPackages(self, __1: GetPreferredPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPreferredPackagesResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, GetPreferredPackagesResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InteractiveSubmissionServiceBlockingStub(InteractiveSubmissionServiceStub):
    def PrepareSubmission(self, __1: PrepareSubmissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PrepareSubmissionResponse: ...
    def ExecuteSubmission(self, __1: ExecuteSubmissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionResponse: ...
    def ExecuteSubmissionAndWait(self, __1: ExecuteSubmissionAndWaitRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionAndWaitResponse: ...
    def ExecuteSubmissionAndWaitForTransaction(self, __1: ExecuteSubmissionAndWaitForTransactionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExecuteSubmissionAndWaitForTransactionResponse: ...
    def GetPreferredPackageVersion(self, __1: GetPreferredPackageVersionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPreferredPackageVersionResponse: ...
    def GetPreferredPackages(self, __1: GetPreferredPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetPreferredPackagesResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InteractiveSubmissionServiceAsyncStub(InteractiveSubmissionServiceStub):
    def PrepareSubmission(self, __1: PrepareSubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PrepareSubmissionResponse]: ...  # type: ignore
    def ExecuteSubmission(self, __1: ExecuteSubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionResponse]: ...  # type: ignore
    def ExecuteSubmissionAndWait(self, __1: ExecuteSubmissionAndWaitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionAndWaitResponse]: ...  # type: ignore
    def ExecuteSubmissionAndWaitForTransaction(self, __1: ExecuteSubmissionAndWaitForTransactionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExecuteSubmissionAndWaitForTransactionResponse]: ...  # type: ignore
    def GetPreferredPackageVersion(self, __1: GetPreferredPackageVersionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetPreferredPackageVersionResponse]: ...  # type: ignore
    def GetPreferredPackages(self, __1: GetPreferredPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetPreferredPackagesResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/health/v30/status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/health/v30/status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/digitalasset/canton/admin/health/v30/status_service.proto\x12(com.digitalasset.canton.admin.health.v30\x1a\x1egoogle/protobuf/duration.proto\"i\n\x13TopologyQueueStatus\x12\x18\n\x07manager\x18\x01 \x01(\rR\x07manager\x12\x1e\n\ndispatcher\x18\x02 \x01(\rR\ndispatcher\x12\x18\n\x07\x63lients\x18\x03 \x01(\rR\x07\x63lients\"\xee\x03\n\x0f\x43omponentStatus\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12V\n\x02ok\x18\x02 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.health.v30.ComponentStatus.StatusDataH\x00R\x02ok\x12\x62\n\x08\x64\x65graded\x18\x03 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.health.v30.ComponentStatus.StatusDataH\x00R\x08\x64\x65graded\x12^\n\x06\x66\x61iled\x18\x04 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.health.v30.ComponentStatus.StatusDataH\x00R\x06\x66\x61iled\x12\\\n\x05\x66\x61tal\x18\x05 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.health.v30.ComponentStatus.StatusDataH\x00R\x05\x66\x61tal\x1a\x43\n\nStatusData\x12%\n\x0b\x64\x65scription\x18\x01 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x08\n\x06status\"\x80\x03\n\x0eNotInitialized\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x8d\x01\n\x1awaiting_for_external_input\x18\x02 \x01(\x0e\x32P.com.digitalasset.canton.admin.health.v30.NotInitialized.WaitingForExternalInputR\x17waitingForExternalInput\"\xc5\x01\n\x17WaitingForExternalInput\x12*\n&WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED\x10\x00\x12!\n\x1dWAITING_FOR_EXTERNAL_INPUT_ID\x10\x01\x12,\n(WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY\x10\x02\x12-\n)WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION\x10\x03\"\xcf\x03\n\x06Status\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12Q\n\x05ports\x18\x03 \x03(\x0b\x32;.com.digitalasset.canton.admin.health.v30.Status.PortsEntryR\x05ports\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x66\n\x0ftopology_queues\x18\x05 \x01(\x0b\x32=.com.digitalasset.canton.admin.health.v30.TopologyQueueStatusR\x0etopologyQueues\x12Y\n\ncomponents\x18\x06 \x03(\x0b\x32\x39.com.digitalasset.canton.admin.health.v30.ComponentStatusR\ncomponents\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x1a\x38\n\nPortsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"F\n\x11HealthDumpRequest\x12\"\n\nchunk_size\x18\x01 \x01(\rH\x00R\tchunkSize\x88\x01\x01\x42\r\n\x0b_chunk_size\"*\n\x12HealthDumpResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"*\n\x12SetLogLevelRequest\x12\x14\n\x05level\x18\x01 \x01(\tR\x05level\"\x15\n\x13SetLogLevelResponse\"\x16\n\x14GetLastErrorsRequest\"\xb4\x01\n\x15GetLastErrorsResponse\x12]\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.admin.health.v30.GetLastErrorsResponse.ErrorR\x06\x65rrors\x1a<\n\x05\x45rror\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"5\n\x18GetLastErrorTraceRequest\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\"7\n\x19GetLastErrorTraceResponse\x12\x1a\n\x08messages\x18\x01 \x03(\tR\x08messages2\xda\x04\n\rStatusService\x12\x89\x01\n\nHealthDump\x12;.com.digitalasset.canton.admin.health.v30.HealthDumpRequest\x1a<.com.digitalasset.canton.admin.health.v30.HealthDumpResponse0\x01\x12\x8a\x01\n\x0bSetLogLevel\x12<.com.digitalasset.canton.admin.health.v30.SetLogLevelRequest\x1a=.com.digitalasset.canton.admin.health.v30.SetLogLevelResponse\x12\x90\x01\n\rGetLastErrors\x12>.com.digitalasset.canton.admin.health.v30.GetLastErrorsRequest\x1a?.com.digitalasset.canton.admin.health.v30.GetLastErrorsResponse\x12\x9c\x01\n\x11GetLastErrorTrace\x12\x42.com.digitalasset.canton.admin.health.v30.GetLastErrorTraceRequest\x1a\x43.com.digitalasset.canton.admin.health.v30.GetLastErrorTraceResponseBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/health/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.health.v30.status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/health/v30'
  _globals['_STATUS_PORTSENTRY']._loaded_options = None
  _globals['_STATUS_PORTSENTRY']._serialized_options = b'8\001'
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_start=139
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_end=244
  _globals['_COMPONENTSTATUS']._serialized_start=247
  _globals['_COMPONENTSTATUS']._serialized_end=741
  _globals['_COMPONENTSTATUS_STATUSDATA']._serialized_start=664
  _globals['_COMPONENTSTATUS_STATUSDATA']._serialized_end=731
  _globals['_NOTINITIALIZED']._serialized_start=744
  _globals['_NOTINITIALIZED']._serialized_end=1128
  _globals['_NOTINITIALIZED_WAITINGFOREXTERNALINPUT']._serialized_start=931
  _globals['_NOTINITIALIZED_WAITINGFOREXTERNALINPUT']._serialized_end=1128
  _globals['_STATUS']._serialized_start=1131
  _globals['_STATUS']._serialized_end=1594
  _globals['_STATUS_PORTSENTRY']._serialized_start=1538
  _globals['_STATUS_PORTSENTRY']._serialized_end=1594
  _globals['_HEALTHDUMPREQUEST']._serialized_start=1596
  _globals['_HEALTHDUMPREQUEST']._serialized_end=1666
  _globals['_HEALTHDUMPRESPONSE']._serialized_start=1668
  _globals['_HEALTHDUMPRESPONSE']._serialized_end=1710
  _globals['_SETLOGLEVELREQUEST']._serialized_start=1712
  _globals['_SETLOGLEVELREQUEST']._serialized_end=1754
  _globals['_SETLOGLEVELRESPONSE']._serialized_start=1756
  _globals['_SETLOGLEVELRESPONSE']._serialized_end=1777
  _globals['_GETLASTERRORSREQUEST']._serialized_start=1779
  _globals['_GETLASTERRORSREQUEST']._serialized_end=1801
  _globals['_GETLASTERRORSRESPONSE']._serialized_start=1804
  _globals['_GETLASTERRORSRESPONSE']._serialized_end=1984
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_start=1924
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_end=1984
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_start=1986
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_end=2039
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_start=2041
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_end=2096
  _globals['_STATUSSERVICE']._serialized_start=2099
  _globals['_STATUSSERVICE']._serialized_end=2701
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerConnectionValidation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SEQUENCER_CONNECTION_VALIDATION_UNSPECIFIED: _ClassVar[SequencerConnectionValidation]
    SEQUENCER_CONNECTION_VALIDATION_DISABLED: _ClassVar[SequencerConnectionValidation]
    SEQUENCER_CONNECTION_VALIDATION_ACTIVE: _ClassVar[SequencerConnectionValidation]
    SEQUENCER_CONNECTION_VALIDATION_ALL: _ClassVar[SequencerConnectionValidation]
    SEQUENCER_CONNECTION_VALIDATION_THRESHOLD_ACTIVE: _ClassVar[SequencerConnectionValidation]
SEQUENCER_CONNECTION_VALIDATION_UNSPECIFIED: SequencerConnectionValidation
SEQUENCER_CONNECTION_VALIDATION_DISABLED: SequencerConnectionValidation
SEQUENCER_CONNECTION_VALIDATION_ACTIVE: SequencerConnectionValidation
SEQUENCER_CONNECTION_VALIDATION_ALL: SequencerConnectionValidation
SEQUENCER_CONNECTION_VALIDATION_THRESHOLD_ACTIVE: SequencerConnectionValidation

class SequencerConnection(_message.Message):
    __slots__ = ("grpc", "alias", "sequencer_id")
    class Grpc(_message.Message):
        __slots__ = ("connections", "transport_security", "custom_trust_certificates")
        CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
        TRANSPORT_SECURITY_FIELD_NUMBER: _ClassVar[int]
        CUSTOM_TRUST_CERTIFICATES_FIELD_NUMBER: _ClassVar[int]
        connections: _containers.RepeatedScalarFieldContainer[str]
        transport_security: bool
        custom_trust_certificates: bytes
        def __init__(self, connections: _Optional[_Iterable[str]] = ..., transport_security: bool = ..., custom_trust_certificates: _Optional[bytes] = ...) -> None: ...
    GRPC_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_ID_FIELD_NUMBER: _ClassVar[int]
    grpc: SequencerConnection.Grpc
    alias: str
    sequencer_id: str
    def __init__(self, grpc: _Optional[_Union[SequencerConnection.Grpc, _Mapping]] = ..., alias: _Optional[str] = ..., sequencer_id: _Optional[str] = ...) -> None: ...

class SequencerConnections(_message.Message):
    __slots__ = ("sequencer_connections", "sequencer_trust_threshold", "submission_request_amplification", "sequencer_liveness_margin", "sequencer_connection_pool_delays")
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_TRUST_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_REQUEST_AMPLIFICATION_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_LIVENESS_MARGIN_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_POOL_DELAYS_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _containers.RepeatedCompositeFieldContainer[SequencerConnection]
    sequencer_trust_threshold: int
    submission_request_amplification: SubmissionRequestAmplification
    sequencer_liveness_margin: int
    sequencer_connection_pool_delays: SequencerConnectionPoolDelays
    def __init__(self, sequencer_connections: _Optional[_Iterable[_Union[SequencerConnection, _Mapping]]] = ..., sequencer_trust_threshold: _Optional[int] = ..., submission_request_amplification: _Optional[_Union[SubmissionRequestAmplification, _Mapping]] = ..., sequencer_liveness_margin: _Optional[int] = ..., sequencer_connection_pool_delays: _Optional[_Union[SequencerConnectionPoolDelays, _Mapping]] = ...) -> None: ...

class SubmissionRequestAmplification(_message.Message):
    __slots__ = ("factor", "patience")
    FACTOR_FIELD_NUMBER: _ClassVar[int]
    PATIENCE_FIELD_NUMBER: _ClassVar[int]
    factor: int
    patience: _duration_pb2.Duration
    def __init__(self, factor: _Optional[int] = ..., patience: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class SequencerConnectionPoolDelays(_message.Message):
    __slots__ = ("min_restart_delay", "max_restart_delay", "subscription_request_delay", "warn_validation_delay")
    MIN_RESTART_DELAY_FIELD_NUMBER: _ClassVar[int]
    MAX_RESTART_DELAY_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_REQUEST_DELAY_FIELD_NUMBER: _ClassVar[int]
    WARN_VALIDATION_DELAY_FIELD_NUMBER: _ClassVar[int]
    min_restart_delay: _duration_pb2.Duration
    max_restart_delay: _duration_pb2.Duration
    subscription_request_delay: _duration_pb2.Duration
    warn_validation_delay: _duration_pb2.Duration
    def __init__(self, min_restart_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_restart_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., subscription_request_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., warn_validation_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
"""Contains shared errors types that can be raised from API functions"""


class UnexpectedStatus(Exception):
    """Raised by api functions when the response status an undocumented status and Client.raise_on_unexpected_status is True"""

    def __init__(self, status_code: int, content: bytes):
        self.status_code = status_code
        self.content = content

        super().__init__(
            f"Unexpected status code: {status_code}\n\nResponse content:\n{content.decode(errors='ignore')}"
        )


__all__ = ["UnexpectedStatus"]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PackageReference(_message.Message):
    __slots__ = ("package_id", "package_name", "package_version")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    package_name: str
    package_version: str
    def __init__(self, package_id: _Optional[str] = ..., package_name: _Optional[str] = ..., package_version: _Optional[str] = ...) -> None: ...

class VettedPackage(_message.Message):
    __slots__ = ("package_id", "valid_from_inclusive", "valid_until_exclusive", "package_name", "package_version")
    PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_VERSION_FIELD_NUMBER: _ClassVar[int]
    package_id: str
    valid_from_inclusive: _timestamp_pb2.Timestamp
    valid_until_exclusive: _timestamp_pb2.Timestamp
    package_name: str
    package_version: str
    def __init__(self, package_id: _Optional[str] = ..., valid_from_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., valid_until_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., package_name: _Optional[str] = ..., package_version: _Optional[str] = ...) -> None: ...

class VettedPackages(_message.Message):
    __slots__ = ("packages", "participant_id", "synchronizer_id", "topology_serial")
    PACKAGES_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    TOPOLOGY_SERIAL_FIELD_NUMBER: _ClassVar[int]
    packages: _containers.RepeatedCompositeFieldContainer[VettedPackage]
    participant_id: str
    synchronizer_id: str
    topology_serial: int
    def __init__(self, packages: _Optional[_Iterable[_Union[VettedPackage, _Mapping]]] = ..., participant_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., topology_serial: _Optional[int] = ...) -> None: ...

class PriorTopologySerial(_message.Message):
    __slots__ = ("prior", "no_prior")
    PRIOR_FIELD_NUMBER: _ClassVar[int]
    NO_PRIOR_FIELD_NUMBER: _ClassVar[int]
    prior: int
    no_prior: _empty_pb2.Empty
    def __init__(self, prior: _Optional[int] = ..., no_prior: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_connection_pb2 import SequencerConnection, SequencerConnectionPoolDelays, SequencerConnectionValidation, SequencerConnections, SubmissionRequestAmplification
from .sequencer_status_service_pb2 import SequencerAdminStatus, SequencerHealthStatus, SequencerStatusRequest, SequencerStatusResponse
from .sequencer_status_service_pb2_grpc import SequencerStatusServiceStub

__all__ = [
    "SequencerAdminStatus",
    "SequencerConnection",
    "SequencerConnectionPoolDelays",
    "SequencerConnectionValidation",
    "SequencerConnections",
    "SequencerHealthStatus",
    "SequencerStatusRequest",
    "SequencerStatusResponse",
    "SequencerStatusServiceStub",
    "SubmissionRequestAmplification",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/party_name_management.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/participant/admin/v0/party_name_management.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/participant/admin/v0/party_name_management.proto\x12,com.digitalasset.canton.participant.admin.v0\"Z\n\x1aSetPartyDisplayNameRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\"\x1d\n\x1bSetPartyDisplayNameResponse2\xc9\x01\n\x1aPartyNameManagementService\x12\xaa\x01\n\x13setPartyDisplayName\x12H.com.digitalasset.canton.participant.admin.v0.SetPartyDisplayNameRequest\x1aI.com.digitalasset.canton.participant.admin.v0.SetPartyDisplayNameResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.party_name_management_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_SETPARTYDISPLAYNAMEREQUEST']._serialized_start=122
  _globals['_SETPARTYDISPLAYNAMEREQUEST']._serialized_end=212
  _globals['_SETPARTYDISPLAYNAMERESPONSE']._serialized_start=214
  _globals['_SETPARTYDISPLAYNAMERESPONSE']._serialized_end=243
  _globals['_PARTYNAMEMANAGEMENTSERVICE']._serialized_start=246
  _globals['_PARTYNAMEMANAGEMENTSERVICE']._serialized_end=447
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import synchronizer_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_synchronizer__parameters__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x05\n\tBaseQuery\x12I\n\x05store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12\x1c\n\tproposals\x18\x02 \x01(\x08R\tproposals\x12Z\n\toperation\x18\x03 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x38\n\x08snapshot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08snapshot\x12\x37\n\nhead_state\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\theadState\x12W\n\x05range\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.topology.admin.v30.BaseQuery.TimeRangeH\x00R\x05range\x12*\n\x11\x66ilter_signed_key\x18\x08 \x01(\tR\x0f\x66ilterSignedKey\x12.\n\x10protocol_version\x18\t \x01(\x05H\x01R\x0fprotocolVersion\x88\x01\x01\x1am\n\tTimeRange\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12\x30\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05untilB\x0c\n\ntime_queryB\x13\n\x11_protocol_versionJ\x04\x08\x04\x10\x05\"\xde\x03\n\nBaseResult\x12I\n\x05store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12\x38\n\tsequenced\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12Z\n\toperation\x18\x05 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12)\n\x10transaction_hash\x18\x06 \x01(\x0cR\x0ftransactionHash\x12\x16\n\x06serial\x18\x07 \x01(\x05R\x06serial\x12\x34\n\x16signed_by_fingerprints\x18\x08 \x03(\tR\x14signedByFingerprints\"\xe4\x01\n\x1eListNamespaceDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbb\x02\n\x1fListNamespaceDelegationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationR\x04item\"\xae\x01\n+ListDecentralizedNamespaceDefinitionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\"\xe2\x02\n,ListDecentralizedNamespaceDefinitionResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse.ResultR\x07results\x1a\xb6\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Z\n\x04item\x18\x02 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionR\x04item\"\xd8\x01\n\x1cListOwnerToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x31\n\x15\x66ilter_key_owner_type\x18\x02 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x03 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xb5\x02\n\x1dListOwnerToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingR\x04item\"\x97\x01\n\x1cListPartyToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xb5\x02\n\x1dListPartyToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingR\x04item\"\x9e\x01\n\'ListSynchronizerTrustCertificateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xd6\x02\n(ListSynchronizerTrustCertificateResponse\x12u\n\x07results\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateResponse.ResultR\x07results\x1a\xb2\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12V\n\x04item\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SynchronizerTrustCertificateR\x04item\"\xa3\x01\n,ListParticipantSynchronizerPermissionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xe5\x02\n-ListParticipantSynchronizerPermissionResponse\x12z\n\x07results\x18\x01 \x03(\x0b\x32`.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionResponse.ResultR\x07results\x1a\xb7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12[\n\x04item\x18\x02 \x01(\x0b\x32G.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerPermissionR\x04item\"\x94\x01\n\x1dListPartyHostingLimitsRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xb8\x02\n\x1eListPartyHostingLimitsResponse\x12k\n\x07results\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsR\x04item\"\xa0\x01\n\x19ListVettedPackagesRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12-\n\x12\x66ilter_participant\x18\x02 \x01(\tR\x11\x66ilterParticipant\"\xac\x02\n\x1aListVettedPackagesResponse\x12g\n\x07results\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse.ResultR\x07results\x1a\xa4\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12H\n\x04item\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesR\x04item\"\xc7\x01\n\x1dListPartyToParticipantRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\"\xb8\x02\n\x1eListPartyToParticipantResponse\x12k\n\x07results\x18\x02 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantR\x04item\"\xb4\x01\n&ListSynchronizerParametersStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xd5\x02\n\'ListSynchronizerParametersStateResponse\x12t\n\x07results\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateResponse.ResultR\x07results\x1a\xb3\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12W\n\x04item\x18\x02 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.DynamicSynchronizerParametersR\x04item\"\xb2\x01\n$ListMediatorSynchronizerStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xcd\x02\n%ListMediatorSynchronizerStateResponse\x12r\n\x07results\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateResponse.ResultR\x07results\x1a\xaf\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12S\n\x04item\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.MediatorSynchronizerStateR\x04item\"\xb3\x01\n%ListSequencerSynchronizerStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xd0\x02\n&ListSequencerSynchronizerStateResponse\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateResponse.ResultR\x07results\x1a\xb0\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12T\n\x04item\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SequencerSynchronizerStateR\x04item\"\xb8\x01\n*ListSynchronizerUpgradeAnnouncementRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xdf\x02\n+ListSynchronizerUpgradeAnnouncementResponse\x12x\n\x07results\x18\x01 \x03(\x0b\x32^.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementResponse.ResultR\x07results\x1a\xb5\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Y\n\x04item\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.SynchronizerUpgradeAnnouncementR\x04item\"\xaf\x01\n\'ListSequencerConnectionSuccessorRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12.\n\x13\x66ilter_sequencer_id\x18\x02 \x01(\tR\x11\x66ilterSequencerId\"\xd6\x02\n(ListSequencerConnectionSuccessorResponse\x12u\n\x07results\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorResponse.ResultR\x07results\x1a\xb2\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12V\n\x04item\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessorR\x04item\"\x1c\n\x1aListAvailableStoresRequest\"o\n\x1bListAvailableStoresResponse\x12P\n\tstore_ids\x18\x01 \x03(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x08storeIds\"\xbc\x01\n\x0eListAllRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"k\n\x0fListAllResponse\x12X\n\x06result\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x06result\"\xcb\x01\n\x1d\x45xportTopologySnapshotRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"6\n\x1e\x45xportTopologySnapshotResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xcd\x01\n\x1f\x45xportTopologySnapshotV2Request\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"8\n ExportTopologySnapshotV2Response\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xcf\x01\n\x13GenesisStateRequest\x12g\n\x12synchronizer_store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdH\x00R\x11synchronizerStore\x88\x01\x01\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB\x15\n\x13_synchronizer_store\",\n\x14GenesisStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xd1\x01\n\x15GenesisStateV2Request\x12g\n\x12synchronizer_store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdH\x00R\x11synchronizerStore\x88\x01\x01\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB\x15\n\x13_synchronizer_store\".\n\x16GenesisStateV2Response\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\x1c\n\x1aLogicalUpgradeStateRequest\"3\n\x1bLogicalUpgradeStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xc4\x1e\n\x1aTopologyManagerReadService\x12\xb2\x01\n\x17ListNamespaceDelegation\x12J.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse\x12\xd9\x01\n$ListDecentralizedNamespaceDefinition\x12W.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionRequest\x1aX.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse\x12\xac\x01\n\x15ListOwnerToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse\x12\xac\x01\n\x15ListPartyToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse\x12\xcd\x01\n ListSynchronizerTrustCertificate\x12S.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateRequest\x1aT.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateResponse\x12\xdc\x01\n%ListParticipantSynchronizerPermission\x12X.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionRequest\x1aY.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionResponse\x12\xaf\x01\n\x16ListPartyHostingLimits\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse\x12\xa3\x01\n\x12ListVettedPackages\x12\x45.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesRequest\x1a\x46.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse\x12\xaf\x01\n\x16ListPartyToParticipant\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse\x12\xca\x01\n\x1fListSynchronizerParametersState\x12R.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateRequest\x1aS.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateResponse\x12\xc4\x01\n\x1dListMediatorSynchronizerState\x12P.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateRequest\x1aQ.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateResponse\x12\xc7\x01\n\x1eListSequencerSynchronizerState\x12Q.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateRequest\x1aR.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateResponse\x12\xd6\x01\n#ListSynchronizerUpgradeAnnouncement\x12V.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementRequest\x1aW.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementResponse\x12\xcd\x01\n ListSequencerConnectionSuccessor\x12S.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorRequest\x1aT.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorResponse\x12\xa6\x01\n\x13ListAvailableStores\x12\x46.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresRequest\x1aG.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresResponse\x12\x82\x01\n\x07ListAll\x12:.com.digitalasset.canton.topology.admin.v30.ListAllRequest\x1a;.com.digitalasset.canton.topology.admin.v30.ListAllResponse\x12\xb1\x01\n\x16\x45xportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotResponse0\x01\x12\xb7\x01\n\x18\x45xportTopologySnapshotV2\x12K.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotV2Request\x1aL.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotV2Response0\x01\x12\x93\x01\n\x0cGenesisState\x12?.com.digitalasset.canton.topology.admin.v30.GenesisStateRequest\x1a@.com.digitalasset.canton.topology.admin.v30.GenesisStateResponse0\x01\x12\x99\x01\n\x0eGenesisStateV2\x12\x41.com.digitalasset.canton.topology.admin.v30.GenesisStateV2Request\x1a\x42.com.digitalasset.canton.topology.admin.v30.GenesisStateV2Response0\x01\x12\xa8\x01\n\x13LogicalUpgradeState\x12\x46.com.digitalasset.canton.topology.admin.v30.LogicalUpgradeStateRequest\x1aG.com.digitalasset.canton.topology.admin.v30.LogicalUpgradeStateResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_read_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_BASEQUERY']._serialized_start=367
  _globals['_BASEQUERY']._serialized_end=1023
  _globals['_BASEQUERY_TIMERANGE']._serialized_start=873
  _globals['_BASEQUERY_TIMERANGE']._serialized_end=982
  _globals['_BASERESULT']._serialized_start=1026
  _globals['_BASERESULT']._serialized_end=1504
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_start=1507
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_end=1735
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_start=1738
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_end=2053
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_start=1884
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_end=2053
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_start=2056
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_end=2230
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_start=2233
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_end=2587
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_start=2405
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_end=2587
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_start=2590
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_end=2806
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_start=2809
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_end=3118
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=2951
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3118
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_start=3121
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_end=3272
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_start=3275
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_end=3584
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=3417
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3584
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATEREQUEST']._serialized_start=3587
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATEREQUEST']._serialized_end=3745
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE']._serialized_start=3748
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE']._serialized_end=4090
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE_RESULT']._serialized_start=3912
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE_RESULT']._serialized_end=4090
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONREQUEST']._serialized_start=4093
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONREQUEST']._serialized_end=4256
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE']._serialized_start=4259
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE']._serialized_end=4616
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE_RESULT']._serialized_start=4433
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE_RESULT']._serialized_end=4616
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_start=4619
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_end=4767
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_start=4770
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_end=5082
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_start=4914
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_end=5082
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_start=5085
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_end=5245
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_start=5248
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_end=5548
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_start=5384
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_end=5548
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_start=5551
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_end=5750
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_start=5753
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_end=6065
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_start=5897
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_end=6065
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATEREQUEST']._serialized_start=6068
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATEREQUEST']._serialized_end=6248
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE']._serialized_start=6251
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE']._serialized_end=6592
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE_RESULT']._serialized_start=6413
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE_RESULT']._serialized_end=6592
  _globals['_LISTMEDIATORSYNCHRONIZERSTATEREQUEST']._serialized_start=6595
  _globals['_LISTMEDIATORSYNCHRONIZERSTATEREQUEST']._serialized_end=6773
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE']._serialized_start=6776
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE']._serialized_end=7109
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_start=6934
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_end=7109
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATEREQUEST']._serialized_start=7112
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATEREQUEST']._serialized_end=7291
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE']._serialized_start=7294
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE']._serialized_end=7630
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_start=7454
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_end=7630
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTREQUEST']._serialized_start=7633
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTREQUEST']._serialized_end=7817
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE']._serialized_start=7820
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE']._serialized_end=8171
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE_RESULT']._serialized_start=7990
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE_RESULT']._serialized_end=8171
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORREQUEST']._serialized_start=8174
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORREQUEST']._serialized_end=8349
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE']._serialized_start=8352
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE']._serialized_end=8694
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE_RESULT']._serialized_start=8516
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE_RESULT']._serialized_end=8694
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_start=8696
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_end=8724
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_start=8726
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_end=8837
  _globals['_LISTALLREQUEST']._serialized_start=8840
  _globals['_LISTALLREQUEST']._serialized_end=9028
  _globals['_LISTALLRESPONSE']._serialized_start=9030
  _globals['_LISTALLRESPONSE']._serialized_end=9137
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=9140
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=9343
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=9345
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=9399
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_start=9402
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_end=9607
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_start=9609
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_end=9665
  _globals['_GENESISSTATEREQUEST']._serialized_start=9668
  _globals['_GENESISSTATEREQUEST']._serialized_end=9875
  _globals['_GENESISSTATERESPONSE']._serialized_start=9877
  _globals['_GENESISSTATERESPONSE']._serialized_end=9921
  _globals['_GENESISSTATEV2REQUEST']._serialized_start=9924
  _globals['_GENESISSTATEV2REQUEST']._serialized_end=10133
  _globals['_GENESISSTATEV2RESPONSE']._serialized_start=10135
  _globals['_GENESISSTATEV2RESPONSE']._serialized_end=10181
  _globals['_LOGICALUPGRADESTATEREQUEST']._serialized_start=10183
  _globals['_LOGICALUPGRADESTATEREQUEST']._serialized_end=10211
  _globals['_LOGICALUPGRADESTATERESPONSE']._serialized_start=10213
  _globals['_LOGICALUPGRADESTATERESPONSE']._serialized_end=10264
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_start=10267
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_end=14175
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExercisedEvent")


@_attrs_define
class ExercisedEvent:
    """Records that a choice has been exercised on a target contract.

    Attributes:
        offset (int): The offset of origin.
            Offsets are managed by the participant nodes.
            Transactions can thus NOT be assumed to have the same offsets on different participant nodes.
            Required, it is a valid absolute offset (positive integer)
        node_id (int): The position of this event in the originating transaction or reassignment.
            Node IDs are not necessarily equal across participants,
            as these may see different projections/parts of transactions.
            Required, must be valid node ID (non-negative integer)
        contract_id (str): The ID of the target contract.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        template_id (str): Identifies the template that defines the executed choice.
            This template's package-id may differ from the target contract's package-id
            if the target contract has been upgraded or downgraded.

            The identifier uses the package-id reference format.

            Required
        choice (str): The choice that was exercised on the target contract.
            Must be a valid NameString (as described in ``value.proto``).
            Required
        choice_argument (Any): The argument of the exercised choice.
            Required
        consuming (bool): If true, the target contract may no longer be exercised.
            Required
        last_descendant_node_id (int): Specifies the upper boundary of the node ids of the events in the same
            transaction that appeared as a result of
            this ``ExercisedEvent``. This allows unambiguous identification of all the members of the subtree rooted at this
            node. A full subtree can be constructed when all descendant nodes are present in the stream. If nodes are
            heavily
            filtered, it is only possible to determine if a node is in a consequent subtree or not.
            Required
        exercise_result (Any): The result of exercising the choice.
            Required
        package_name (str): The package name of the contract.
            Required
        acs_delta (bool): Whether this event would be part of respective ACS_DELTA shaped stream,
            and should therefore considered when tracking contract activeness on the client-side.
            Required
        interface_id (str | Unset): The interface where the choice is defined, if inherited.
            If defined, the identifier uses the package-id reference format.

            Optional
        acting_parties (list[str] | Unset): The parties that exercised the choice.
            Each element must be a valid PartyIdString (as described in ``value.proto``).
            Required
        witness_parties (list[str] | Unset): The parties that are notified of this event. The witnesses of an exercise
            node will depend on whether the exercise was consuming or not.
            If consuming, the witnesses are the union of the stakeholders,
            the actors and all informees of all the ancestors of this event this
            participant knows about.
            If not consuming, the witnesses are the union of the signatories,
            the actors and all informees of all the ancestors of this event this
            participant knows about.
            In both cases the witnesses are limited to the querying parties, or not
            limited in case anyParty filters are used.
            Note that the actors might not necessarily be observers
            and thus stakeholders. This is the case when the controllers of a
            choice are specified using "flexible controllers", using the
            ``choice ... controller`` syntax, and said controllers are not
            explicitly marked as observers.
            Each element must be a valid PartyIdString (as described in ``value.proto``).
            Required
        implemented_interfaces (list[str] | Unset): If the event is consuming, the interfaces implemented by the target
            template that have been
            matched from the interface filter query.
            Populated only in case interface filters with include_interface_view set.

            The identifier uses the package-id reference format.

            Optional
    """

    offset: int
    node_id: int
    contract_id: str
    template_id: str
    choice: str
    choice_argument: Any
    consuming: bool
    last_descendant_node_id: int
    exercise_result: Any
    package_name: str
    acs_delta: bool
    interface_id: str | Unset = UNSET
    acting_parties: list[str] | Unset = UNSET
    witness_parties: list[str] | Unset = UNSET
    implemented_interfaces: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        offset = self.offset

        node_id = self.node_id

        contract_id = self.contract_id

        template_id = self.template_id

        choice = self.choice

        choice_argument = self.choice_argument

        consuming = self.consuming

        last_descendant_node_id = self.last_descendant_node_id

        exercise_result = self.exercise_result

        package_name = self.package_name

        acs_delta = self.acs_delta

        interface_id = self.interface_id

        acting_parties: list[str] | Unset = UNSET
        if not isinstance(self.acting_parties, Unset):
            acting_parties = self.acting_parties

        witness_parties: list[str] | Unset = UNSET
        if not isinstance(self.witness_parties, Unset):
            witness_parties = self.witness_parties

        implemented_interfaces: list[str] | Unset = UNSET
        if not isinstance(self.implemented_interfaces, Unset):
            implemented_interfaces = self.implemented_interfaces

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "offset": offset,
                "nodeId": node_id,
                "contractId": contract_id,
                "templateId": template_id,
                "choice": choice,
                "choiceArgument": choice_argument,
                "consuming": consuming,
                "lastDescendantNodeId": last_descendant_node_id,
                "exerciseResult": exercise_result,
                "packageName": package_name,
                "acsDelta": acs_delta,
            }
        )
        if interface_id is not UNSET:
            field_dict["interfaceId"] = interface_id
        if acting_parties is not UNSET:
            field_dict["actingParties"] = acting_parties
        if witness_parties is not UNSET:
            field_dict["witnessParties"] = witness_parties
        if implemented_interfaces is not UNSET:
            field_dict["implementedInterfaces"] = implemented_interfaces

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        offset = d.pop("offset")

        node_id = d.pop("nodeId")

        contract_id = d.pop("contractId")

        template_id = d.pop("templateId")

        choice = d.pop("choice")

        choice_argument = d.pop("choiceArgument")

        consuming = d.pop("consuming")

        last_descendant_node_id = d.pop("lastDescendantNodeId")

        exercise_result = d.pop("exerciseResult")

        package_name = d.pop("packageName")

        acs_delta = d.pop("acsDelta")

        interface_id = d.pop("interfaceId", UNSET)

        acting_parties = cast(list[str], d.pop("actingParties", UNSET))

        witness_parties = cast(list[str], d.pop("witnessParties", UNSET))

        implemented_interfaces = cast(list[str], d.pop("implementedInterfaces", UNSET))

        exercised_event = cls(
            offset=offset,
            node_id=node_id,
            contract_id=contract_id,
            template_id=template_id,
            choice=choice,
            choice_argument=choice_argument,
            consuming=consuming,
            last_descendant_node_id=last_descendant_node_id,
            exercise_result=exercise_result,
            package_name=package_name,
            acs_delta=acs_delta,
            interface_id=interface_id,
            acting_parties=acting_parties,
            witness_parties=witness_parties,
            implemented_interfaces=implemented_interfaces,
        )

        exercised_event.additional_properties = d
        return exercised_event

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import commands_pb2 as _commands_pb2
from . import reassignment_pb2 as _reassignment_pb2
from . import reassignment_commands_pb2 as _reassignment_commands_pb2
from . import transaction_pb2 as _transaction_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmitAndWaitRequest(_message.Message):
    __slots__ = ("commands",)
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    commands: _commands_pb2.Commands
    def __init__(self, commands: _Optional[_Union[_commands_pb2.Commands, _Mapping]] = ...) -> None: ...

class SubmitAndWaitForTransactionRequest(_message.Message):
    __slots__ = ("commands", "transaction_format")
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_FORMAT_FIELD_NUMBER: _ClassVar[int]
    commands: _commands_pb2.Commands
    transaction_format: _transaction_filter_pb2.TransactionFormat
    def __init__(self, commands: _Optional[_Union[_commands_pb2.Commands, _Mapping]] = ..., transaction_format: _Optional[_Union[_transaction_filter_pb2.TransactionFormat, _Mapping]] = ...) -> None: ...

class SubmitAndWaitResponse(_message.Message):
    __slots__ = ("update_id", "completion_offset")
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    COMPLETION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    update_id: str
    completion_offset: int
    def __init__(self, update_id: _Optional[str] = ..., completion_offset: _Optional[int] = ...) -> None: ...

class SubmitAndWaitForTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: _transaction_pb2.Transaction
    def __init__(self, transaction: _Optional[_Union[_transaction_pb2.Transaction, _Mapping]] = ...) -> None: ...

class SubmitAndWaitForReassignmentRequest(_message.Message):
    __slots__ = ("reassignment_commands", "event_format")
    REASSIGNMENT_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    EVENT_FORMAT_FIELD_NUMBER: _ClassVar[int]
    reassignment_commands: _reassignment_commands_pb2.ReassignmentCommands
    event_format: _transaction_filter_pb2.EventFormat
    def __init__(self, reassignment_commands: _Optional[_Union[_reassignment_commands_pb2.ReassignmentCommands, _Mapping]] = ..., event_format: _Optional[_Union[_transaction_filter_pb2.EventFormat, _Mapping]] = ...) -> None: ...

class SubmitAndWaitForReassignmentResponse(_message.Message):
    __slots__ = ("reassignment",)
    REASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    reassignment: _reassignment_pb2.Reassignment
    def __init__(self, reassignment: _Optional[_Union[_reassignment_pb2.Reassignment, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v0 import topology_pb2 as _topology_pb2
from ..v1 import topology_pb2 as _topology_pb2_1
from . import domain_params_pb2 as _domain_params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyStateUpdate(_message.Message):
    __slots__ = ("operation", "id", "namespace_delegation", "identifier_delegation", "owner_to_key_mapping", "party_to_participant", "signed_legal_identity_claim", "participant_state", "vetted_packages", "check_only_packages", "mediator_domain_state")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    OWNER_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SIGNED_LEGAL_IDENTITY_CLAIM_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_STATE_FIELD_NUMBER: _ClassVar[int]
    VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    CHECK_ONLY_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DOMAIN_STATE_FIELD_NUMBER: _ClassVar[int]
    operation: _topology_pb2.TopologyChangeOp
    id: str
    namespace_delegation: _topology_pb2.NamespaceDelegation
    identifier_delegation: _topology_pb2.IdentifierDelegation
    owner_to_key_mapping: _topology_pb2.OwnerToKeyMapping
    party_to_participant: _topology_pb2.PartyToParticipant
    signed_legal_identity_claim: _topology_pb2.SignedLegalIdentityClaim
    participant_state: _topology_pb2.ParticipantState
    vetted_packages: _topology_pb2.VettedPackages
    check_only_packages: _topology_pb2.CheckOnlyPackages
    mediator_domain_state: _topology_pb2.MediatorDomainState
    def __init__(self, operation: _Optional[_Union[_topology_pb2.TopologyChangeOp, str]] = ..., id: _Optional[str] = ..., namespace_delegation: _Optional[_Union[_topology_pb2.NamespaceDelegation, _Mapping]] = ..., identifier_delegation: _Optional[_Union[_topology_pb2.IdentifierDelegation, _Mapping]] = ..., owner_to_key_mapping: _Optional[_Union[_topology_pb2.OwnerToKeyMapping, _Mapping]] = ..., party_to_participant: _Optional[_Union[_topology_pb2.PartyToParticipant, _Mapping]] = ..., signed_legal_identity_claim: _Optional[_Union[_topology_pb2.SignedLegalIdentityClaim, _Mapping]] = ..., participant_state: _Optional[_Union[_topology_pb2.ParticipantState, _Mapping]] = ..., vetted_packages: _Optional[_Union[_topology_pb2.VettedPackages, _Mapping]] = ..., check_only_packages: _Optional[_Union[_topology_pb2.CheckOnlyPackages, _Mapping]] = ..., mediator_domain_state: _Optional[_Union[_topology_pb2.MediatorDomainState, _Mapping]] = ...) -> None: ...

class DomainParametersChange(_message.Message):
    __slots__ = ("domain", "domain_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    domain_parameters: _domain_params_pb2.DynamicDomainParameters
    def __init__(self, domain: _Optional[str] = ..., domain_parameters: _Optional[_Union[_domain_params_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...

class DomainGovernanceTransaction(_message.Message):
    __slots__ = ("domain_parameters_change",)
    DOMAIN_PARAMETERS_CHANGE_FIELD_NUMBER: _ClassVar[int]
    domain_parameters_change: DomainParametersChange
    def __init__(self, domain_parameters_change: _Optional[_Union[DomainParametersChange, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("state_update", "domain_governance")
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    state_update: _topology_pb2_1.TopologyStateUpdate
    domain_governance: DomainGovernanceTransaction
    def __init__(self, state_update: _Optional[_Union[_topology_pb2_1.TopologyStateUpdate, _Mapping]] = ..., domain_governance: _Optional[_Union[DomainGovernanceTransaction, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Challenge(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("member", "member_protocol_versions")
        MEMBER_FIELD_NUMBER: _ClassVar[int]
        MEMBER_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        member: str
        member_protocol_versions: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, member: _Optional[str] = ..., member_protocol_versions: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("success", "failure")
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: Challenge.Success
        failure: Challenge.Failure
        def __init__(self, success: _Optional[_Union[Challenge.Success, _Mapping]] = ..., failure: _Optional[_Union[Challenge.Failure, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ("domain_version", "nonce", "fingerprints")
        DOMAIN_VERSION_FIELD_NUMBER: _ClassVar[int]
        NONCE_FIELD_NUMBER: _ClassVar[int]
        FINGERPRINTS_FIELD_NUMBER: _ClassVar[int]
        domain_version: str
        nonce: bytes
        fingerprints: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, domain_version: _Optional[str] = ..., nonce: _Optional[bytes] = ..., fingerprints: _Optional[_Iterable[str]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("code", "reason")
        CODE_FIELD_NUMBER: _ClassVar[int]
        REASON_FIELD_NUMBER: _ClassVar[int]
        code: int
        reason: str
        def __init__(self, code: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class Authentication(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("member", "signature", "nonce")
        MEMBER_FIELD_NUMBER: _ClassVar[int]
        SIGNATURE_FIELD_NUMBER: _ClassVar[int]
        NONCE_FIELD_NUMBER: _ClassVar[int]
        member: str
        signature: _crypto_pb2.Signature
        nonce: bytes
        def __init__(self, member: _Optional[str] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., nonce: _Optional[bytes] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("success", "failure")
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: Authentication.Success
        failure: Authentication.Failure
        def __init__(self, success: _Optional[_Union[Authentication.Success, _Mapping]] = ..., failure: _Optional[_Union[Authentication.Failure, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ("token", "expires_at")
        TOKEN_FIELD_NUMBER: _ClassVar[int]
        EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
        token: bytes
        expires_at: _timestamp_pb2.Timestamp
        def __init__(self, token: _Optional[bytes] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("code", "reason")
        CODE_FIELD_NUMBER: _ClassVar[int]
        REASON_FIELD_NUMBER: _ClassVar[int]
        code: int
        reason: str
        def __init__(self, code: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UnassignedEvent")


@_attrs_define
class UnassignedEvent:
    """Records that a contract has been unassigned, and it becomes unusable on the source synchronizer

    Attributes:
        reassignment_id (str): The ID of the unassignment. This needs to be used as an input for a assign
            ReassignmentCommand.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        contract_id (str): The ID of the reassigned contract.
            Must be a valid LedgerString (as described in ``value.proto``).
            Required
        source (str): The ID of the source synchronizer
            Must be a valid synchronizer id
            Required
        target (str): The ID of the target synchronizer
            Must be a valid synchronizer id
            Required
        submitter (str): Party on whose behalf the unassign command was executed.
            Empty if the unassignment happened offline via the repair service.
            Must be a valid PartyIdString (as described in ``value.proto``).
            Optional
        reassignment_counter (int): Each corresponding assigned and unassigned event has the same reassignment_counter.
            This strictly increases
            with each unassign command for the same contract. Creation of the contract corresponds to reassignment_counter
            equals zero.
            Required
        package_name (str): The package name of the contract.
            Required
        offset (int): The offset of origin.
            Offsets are managed by the participant nodes.
            Reassignments can thus NOT be assumed to have the same offsets on different participant nodes.
            Required, it is a valid absolute offset (positive integer)
        node_id (int): The position of this event in the originating reassignment.
            Node IDs are not necessarily equal across participants,
            as these may see different projections/parts of reassignments.
            Required, must be valid node ID (non-negative integer)
        template_id (str | Unset): The template of the reassigned contract.
            The identifier uses the package-id reference format.

            Required
        assignment_exclusivity (str | Unset): Assignment exclusivity
            Before this time (measured on the target synchronizer), only the submitter of the unassignment can initiate the
            assignment
            Defined for reassigning participants.
            Optional
        witness_parties (list[str] | Unset): The parties that are notified of this event.
            Required
    """

    reassignment_id: str
    contract_id: str
    source: str
    target: str
    submitter: str
    reassignment_counter: int
    package_name: str
    offset: int
    node_id: int
    template_id: str | Unset = UNSET
    assignment_exclusivity: str | Unset = UNSET
    witness_parties: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        reassignment_id = self.reassignment_id

        contract_id = self.contract_id

        source = self.source

        target = self.target

        submitter = self.submitter

        reassignment_counter = self.reassignment_counter

        package_name = self.package_name

        offset = self.offset

        node_id = self.node_id

        template_id = self.template_id

        assignment_exclusivity = self.assignment_exclusivity

        witness_parties: list[str] | Unset = UNSET
        if not isinstance(self.witness_parties, Unset):
            witness_parties = self.witness_parties

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "reassignmentId": reassignment_id,
                "contractId": contract_id,
                "source": source,
                "target": target,
                "submitter": submitter,
                "reassignmentCounter": reassignment_counter,
                "packageName": package_name,
                "offset": offset,
                "nodeId": node_id,
            }
        )
        if template_id is not UNSET:
            field_dict["templateId"] = template_id
        if assignment_exclusivity is not UNSET:
            field_dict["assignmentExclusivity"] = assignment_exclusivity
        if witness_parties is not UNSET:
            field_dict["witnessParties"] = witness_parties

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        reassignment_id = d.pop("reassignmentId")

        contract_id = d.pop("contractId")

        source = d.pop("source")

        target = d.pop("target")

        submitter = d.pop("submitter")

        reassignment_counter = d.pop("reassignmentCounter")

        package_name = d.pop("packageName")

        offset = d.pop("offset")

        node_id = d.pop("nodeId")

        template_id = d.pop("templateId", UNSET)

        assignment_exclusivity = d.pop("assignmentExclusivity", UNSET)

        witness_parties = cast(list[str], d.pop("witnessParties", UNSET))

        unassigned_event = cls(
            reassignment_id=reassignment_id,
            contract_id=contract_id,
            source=source,
            target=target,
            submitter=submitter,
            reassignment_counter=reassignment_counter,
            package_name=package_name,
            offset=offset,
            node_id=node_id,
            template_id=template_id,
            assignment_exclusivity=assignment_exclusivity,
            witness_parties=witness_parties,
        )

        unassigned_event.additional_properties = d
        return unassigned_event

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.package_reference import PackageReference


T = TypeVar("T", bound="GetPreferredPackagesResponse")


@_attrs_define
class GetPreferredPackagesResponse:
    """
    Attributes:
        synchronizer_id (str): The synchronizer for which the package preferences are computed.
            If the synchronizer_id was specified in the request, then it matches the request synchronizer_id.
            Required
        package_references (list[PackageReference] | Unset): The package references of the preferred packages.
            Must contain one package reference for each requested package-name.

            If you build command submissions whose content depends on the returned
            preferred packages, then we recommend submitting the preferred package-ids
            in the ``package_id_selection_preference`` of the command submission to
            avoid race conditions with concurrent changes of the on-ledger package vetting state.

            Required
    """

    synchronizer_id: str
    package_references: list[PackageReference] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        synchronizer_id = self.synchronizer_id

        package_references: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.package_references, Unset):
            package_references = []
            for package_references_item_data in self.package_references:
                package_references_item = package_references_item_data.to_dict()
                package_references.append(package_references_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "synchronizerId": synchronizer_id,
            }
        )
        if package_references is not UNSET:
            field_dict["packageReferences"] = package_references

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.package_reference import PackageReference

        d = dict(src_dict)
        synchronizer_id = d.pop("synchronizerId")

        _package_references = d.pop("packageReferences", UNSET)
        package_references: list[PackageReference] | Unset = UNSET
        if _package_references is not UNSET:
            package_references = []
            for package_references_item_data in _package_references:
                package_references_item = PackageReference.from_dict(
                    package_references_item_data
                )

                package_references.append(package_references_item)

        get_preferred_packages_response = cls(
            synchronizer_id=synchronizer_id,
            package_references=package_references,
        )

        get_preferred_packages_response.additional_properties = d
        return get_preferred_packages_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.signature import Signature
    from ..models.signed_transaction import SignedTransaction


T = TypeVar("T", bound="AllocateExternalPartyRequest")


@_attrs_define
class AllocateExternalPartyRequest:
    """Required authorization: ``HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)``

    Attributes:
        synchronizer (str): TODO(#27670) support synchronizer aliases
            Synchronizer ID on which to onboard the party
            Required
        identity_provider_id (str): The id of the ``Identity Provider``
            If not set, assume the party is managed by the default identity provider.
            Optional
        onboarding_transactions (list[SignedTransaction] | Unset): TopologyTransactions to onboard the external party
            Can contain:
            - A namespace for the party.
            This can be either a single NamespaceDelegation,
            or DecentralizedNamespaceDefinition along with its authorized namespace owners in the form of
            NamespaceDelegations.
            May be provided, if so it must be fully authorized by the signatures in this request combined with the existing
            topology state.
            - A PartyToKeyMapping to register the party's signing keys.
            May be provided, if so it must be fully authorized by the signatures in this request combined with the existing
            topology state.
            - A PartyToParticipant to register the hosting relationship of the party.
            Must be provided.
            Required
        multi_hash_signatures (list[Signature] | Unset): Optional signatures of the combined hash of all
            onboarding_transactions
            This may be used instead of providing signatures on each individual transaction
    """

    synchronizer: str
    identity_provider_id: str
    onboarding_transactions: list[SignedTransaction] | Unset = UNSET
    multi_hash_signatures: list[Signature] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        synchronizer = self.synchronizer

        identity_provider_id = self.identity_provider_id

        onboarding_transactions: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.onboarding_transactions, Unset):
            onboarding_transactions = []
            for onboarding_transactions_item_data in self.onboarding_transactions:
                onboarding_transactions_item = (
                    onboarding_transactions_item_data.to_dict()
                )
                onboarding_transactions.append(onboarding_transactions_item)

        multi_hash_signatures: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.multi_hash_signatures, Unset):
            multi_hash_signatures = []
            for multi_hash_signatures_item_data in self.multi_hash_signatures:
                multi_hash_signatures_item = multi_hash_signatures_item_data.to_dict()
                multi_hash_signatures.append(multi_hash_signatures_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "synchronizer": synchronizer,
                "identityProviderId": identity_provider_id,
            }
        )
        if onboarding_transactions is not UNSET:
            field_dict["onboardingTransactions"] = onboarding_transactions
        if multi_hash_signatures is not UNSET:
            field_dict["multiHashSignatures"] = multi_hash_signatures

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.signature import Signature
        from ..models.signed_transaction import SignedTransaction

        d = dict(src_dict)
        synchronizer = d.pop("synchronizer")

        identity_provider_id = d.pop("identityProviderId")

        _onboarding_transactions = d.pop("onboardingTransactions", UNSET)
        onboarding_transactions: list[SignedTransaction] | Unset = UNSET
        if _onboarding_transactions is not UNSET:
            onboarding_transactions = []
            for onboarding_transactions_item_data in _onboarding_transactions:
                onboarding_transactions_item = SignedTransaction.from_dict(
                    onboarding_transactions_item_data
                )

                onboarding_transactions.append(onboarding_transactions_item)

        _multi_hash_signatures = d.pop("multiHashSignatures", UNSET)
        multi_hash_signatures: list[Signature] | Unset = UNSET
        if _multi_hash_signatures is not UNSET:
            multi_hash_signatures = []
            for multi_hash_signatures_item_data in _multi_hash_signatures:
                multi_hash_signatures_item = Signature.from_dict(
                    multi_hash_signatures_item_data
                )

                multi_hash_signatures.append(multi_hash_signatures_item)

        allocate_external_party_request = cls(
            synchronizer=synchronizer,
            identity_provider_id=identity_provider_id,
            onboarding_transactions=onboarding_transactions,
            multi_hash_signatures=multi_hash_signatures,
        )

        allocate_external_party_request.additional_properties = d
        return allocate_external_party_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VerdictResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VERDICT_RESULT_UNSPECIFIED: _ClassVar[VerdictResult]
    VERDICT_RESULT_ACCEPTED: _ClassVar[VerdictResult]
    VERDICT_RESULT_REJECTED: _ClassVar[VerdictResult]
VERDICT_RESULT_UNSPECIFIED: VerdictResult
VERDICT_RESULT_ACCEPTED: VerdictResult
VERDICT_RESULT_REJECTED: VerdictResult

class VerdictsRequest(_message.Message):
    __slots__ = ("most_recently_received_record_time",)
    MOST_RECENTLY_RECEIVED_RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    most_recently_received_record_time: _timestamp_pb2.Timestamp
    def __init__(self, most_recently_received_record_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class VerdictsResponse(_message.Message):
    __slots__ = ("verdict",)
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    verdict: Verdict
    def __init__(self, verdict: _Optional[_Union[Verdict, _Mapping]] = ...) -> None: ...

class Verdict(_message.Message):
    __slots__ = ("submitting_parties", "submitting_participant_uid", "verdict", "finalization_time", "record_time", "mediator_group", "transaction_views", "update_id")
    SUBMITTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    SUBMITTING_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    FINALIZATION_TIME_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_GROUP_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_VIEWS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    submitting_parties: _containers.RepeatedScalarFieldContainer[str]
    submitting_participant_uid: str
    verdict: VerdictResult
    finalization_time: _timestamp_pb2.Timestamp
    record_time: _timestamp_pb2.Timestamp
    mediator_group: int
    transaction_views: TransactionViews
    update_id: str
    def __init__(self, submitting_parties: _Optional[_Iterable[str]] = ..., submitting_participant_uid: _Optional[str] = ..., verdict: _Optional[_Union[VerdictResult, str]] = ..., finalization_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., record_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., mediator_group: _Optional[int] = ..., transaction_views: _Optional[_Union[TransactionViews, _Mapping]] = ..., update_id: _Optional[str] = ...) -> None: ...

class TransactionViews(_message.Message):
    __slots__ = ("views", "root_views")
    class ViewsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: TransactionView
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[TransactionView, _Mapping]] = ...) -> None: ...
    VIEWS_FIELD_NUMBER: _ClassVar[int]
    ROOT_VIEWS_FIELD_NUMBER: _ClassVar[int]
    views: _containers.MessageMap[int, TransactionView]
    root_views: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, views: _Optional[_Mapping[int, TransactionView]] = ..., root_views: _Optional[_Iterable[int]] = ...) -> None: ...

class TransactionView(_message.Message):
    __slots__ = ("informees", "confirming_parties", "sub_views")
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    CONFIRMING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    SUB_VIEWS_FIELD_NUMBER: _ClassVar[int]
    informees: _containers.RepeatedScalarFieldContainer[str]
    confirming_parties: _containers.RepeatedCompositeFieldContainer[Quorum]
    sub_views: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, informees: _Optional[_Iterable[str]] = ..., confirming_parties: _Optional[_Iterable[_Union[Quorum, _Mapping]]] = ..., sub_views: _Optional[_Iterable[int]] = ...) -> None: ...

class Quorum(_message.Message):
    __slots__ = ("parties", "threshold")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    threshold: int
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., threshold: _Optional[int] = ...) -> None: ...
